universal_file_viewer library
Classes
- UniversalFileViewer
- VideoPlayerWidget
- A widget that displays a video from the given file path.
- VideoPlayerWidgetState
Enums
Functions
-
detectFileType(
String path) → FileType? - Detect the file type of the given file path.
-
supportedFile(
String path) → bool